@@ -17,7 +17,6 @@ import collections.abc
 import dataclasses
 import typing
 
-import jsonschema
 import luigi
 import typing_extensions
 from luigi.freezing import FrozenOrderedDict
@@ -34,61 +33,6 @@ class ExtParameter(luigi.Parameter):
         return x
 
 
-def recursively_unfreeze(value):
-    """Recursively unfreeze a value."""
-    if isinstance(value, collections.abc.Mapping):
-        return dict(((k, recursively_unfreeze(v)) for k, v in value.items()))
-    elif isinstance(value, (list, tuple)):
-        return list(recursively_unfreeze(v) for v in value)
-    return value
-
-
-class DictParameter(luigi.DictParameter):
-    """Class to parse dict parameters with optional schema."""
-
-    def __init__(
-        self,
-        *args,
-        schema=None,
-        **kwargs,
-    ):
-        self.schema = schema
-        super().__init__(
-            *args,
-            **kwargs,
-        )
-
-    def normalize(self, value):
-        """Convert the value to a FrozenOrderedDict so it can be hashed."""
-        normalized_value = super().normalize(value)
-        if self.schema is not None:
-            jsonschema.validate(instance=recursively_unfreeze(normalized_value), schema=self.schema)
-        return normalized_value
-
-
-class ListParameter(luigi.ListParameter):
-    """Class to parse list parameters with optional schema."""
-
-    def __init__(
-        self,
-        *args,
-        schema=None,
-        **kwargs,
-    ):
-        self.schema = schema
-        super().__init__(
-            *args,
-            **kwargs,
-        )
-
-    def normalize(self, x):
-        """Convert the value to a FrozenOrderedDict so it can be hashed."""
-        normalized_value = super().normalize(x)
-        if self.schema is not None:
-            jsonschema.validate(instance=recursively_unfreeze(normalized_value), schema=self.schema)
-        return normalized_value
-
-
 class RatioParameter(luigi.NumericalParameter):
     """Class to parse ratio parameters.
 
@@ -161,7 +105,6 @@ class DataclassParameter(luigi.DictParameter):
     """
 
     def __init__(self, cls_type, *args, **kwargs):
-
         if not _is_dataclass(cls_type):
             raise TypeError(f"Class type {cls_type.__name__!r} is not a dataclass.")
 
@@ -181,7 +124,6 @@ class DataclassParameter(luigi.DictParameter):
 
 
 def _instantiate(cls, data):
-
     # pylint: disable=too-many-return-statements
 
     if data is None:
@@ -234,7 +176,6 @@ def _get_type_args(cls):
 
 
 def _instantiate_sequence(cls, data, func):
-
     args = _get_type_args(cls)
 
     # Use type annotation to cast the sequence values
@@ -254,7 +195,6 @@ def _instantiate_mapping(cls, data, func):
 
     # Use key, value type annotations for casting
     if args:
-
         assert len(args) == 2, args
         arguments_generator = (
             (
