@@ -29,7 +29,6 @@ import warnings
 import luigi
 import mock
 import pytest
-from jsonschema.exceptions import ValidationError
 from luigi.freezing import FrozenOrderedDict
 
 import luigi_tools.parameter
@@ -71,160 +70,6 @@ def test_ext_parameter(luigi_tools_working_directory):
         assert luigi.build([TaskExtParameter(test_type="cfg_with_dot")], local_scheduler=True)
 
 
-def test_dict_parameter(luigi_tools_working_directory):
-    """Test the `luigi_tools.parameter.DictParameter` class."""
-
-    class TaskDictParameter(luigi.Task):
-        """A simple test task."""
-
-        a = luigi_tools.parameter.DictParameter(default={"a": 0})
-        b = luigi_tools.parameter.DictParameter(
-            default={"INVALID_ATTRIBUTE": 0},
-            schema={
-                "type": "object",
-                "properties": {
-                    "an_int": {"type": "integer"},
-                    "an_optional_str": {"type": "string"},
-                },
-                "additionalProperties": False,
-                "required": ["an_int"],
-            },
-        )
-
-        def run(self):
-            create_empty_file(self.output().path)
-
-        def output(self):
-            return luigi.LocalTarget(
-                luigi_tools_working_directory
-                / f"test_dict_parameter_{hash(self.a)}_{hash(self.b)}.test"
-            )
-
-    # Check that the default value is validated
-    with pytest.raises(
-        ValidationError,
-        match=r"Additional properties are not allowed \('INVALID_ATTRIBUTE' was unexpected\)",
-    ):
-        luigi.build([TaskDictParameter()], local_scheduler=True)
-
-    # Check that empty dict is not valid
-    empty_dict = {}
-    with pytest.raises(ValidationError, match="'an_int' is a required property"):
-        luigi.build([TaskDictParameter(a=empty_dict, b=empty_dict)], local_scheduler=True)
-
-    # Check that valid dicts work
-    valid_dict = {"an_int": 1}
-    valid_and_complete_dict = {"an_int": 1, "an_optional_str": "hello"}
-    assert luigi.build([TaskDictParameter(a=valid_dict, b=valid_dict)], local_scheduler=True)
-    assert luigi.build(
-        [TaskDictParameter(a=valid_and_complete_dict, b=valid_and_complete_dict)],
-        local_scheduler=True,
-    )
-
-    with set_luigi_config(
-        {"TaskDictParameter": {"a": json.dumps(valid_dict), "b": json.dumps(valid_dict)}}
-    ):
-        assert luigi.build([TaskDictParameter()], local_scheduler=True)
-
-    with set_luigi_config(
-        {
-            "TaskDictParameter": {
-                "a": json.dumps(valid_and_complete_dict),
-                "b": json.dumps(valid_and_complete_dict),
-            }
-        }
-    ):
-        assert luigi.build([TaskDictParameter()], local_scheduler=True)
-
-    # Check that invalid dicts raise correct errors
-    invalid_dict = {"an_int": "999"}
-    invalid_and_complete_dict = {"an_int": 1, "an_optional_str": 999}
-    with set_luigi_config(
-        {"TaskDictParameter": {"a": json.dumps(invalid_dict), "b": json.dumps(invalid_dict)}}
-    ):
-        with pytest.raises(ValidationError, match="'999' is not of type 'integer'"):
-            luigi.build([TaskDictParameter()], local_scheduler=True)
-
-    with set_luigi_config(
-        {
-            "TaskDictParameter": {
-                "a": json.dumps(invalid_and_complete_dict),
-                "b": json.dumps(invalid_and_complete_dict),
-            }
-        }
-    ):
-        with pytest.raises(ValidationError, match="999 is not of type 'string'"):
-            luigi.build([TaskDictParameter()], local_scheduler=True)
-
-
-def test_list_parameter(luigi_tools_working_directory):
-    """Test the `luigi_tools.parameter.ListParameter` class."""
-
-    class TaskListParameter(luigi.Task):
-        """A simple test task."""
-
-        a = luigi_tools.parameter.ListParameter(default=[1, 2])
-        b = luigi_tools.parameter.ListParameter(
-            default=["INVALID_ATTRIBUTE"],
-            schema={"type": "array", "items": {"type": "integer", "minimum": 10}, "minItems": 1},
-        )
-
-        def run(self):
-            create_empty_file(self.output().path)
-
-        def output(self):
-            return luigi.LocalTarget(
-                luigi_tools_working_directory
-                / f"test_list_parameter_{hash(self.a)}_{hash(self.b)}.test"
-            )
-
-    # Check that the default value is validated
-    with pytest.raises(
-        ValidationError,
-        match=r"'INVALID_ATTRIBUTE' is not of type 'integer'",
-    ):
-        luigi.build([TaskListParameter()], local_scheduler=True)
-
-    # Check that empty list is not valid
-    empty_list = []
-    with pytest.raises(ValidationError, match=r"\[\] is too short"):
-        luigi.build([TaskListParameter(a=empty_list, b=empty_list)], local_scheduler=True)
-
-    # Check that valid lists work
-    valid_list = [11, 12, 13]
-    assert luigi.build([TaskListParameter(a=valid_list, b=valid_list)], local_scheduler=True)
-
-    with set_luigi_config(
-        {"TaskListParameter": {"a": json.dumps(valid_list), "b": json.dumps(valid_list)}}
-    ):
-        assert luigi.build([TaskListParameter()], local_scheduler=True)
-
-    # Check that invalid lists raise correct errors
-    invalid_list_type = ["NOT AN INT"]
-    invalid_list_value = [1, 2, 3]
-    with set_luigi_config(
-        {
-            "TaskListParameter": {
-                "a": json.dumps(invalid_list_type),
-                "b": json.dumps(invalid_list_type),
-            }
-        }
-    ):
-        with pytest.raises(ValidationError, match="'NOT AN INT' is not of type 'integer'"):
-            luigi.build([TaskListParameter()], local_scheduler=True)
-
-    with set_luigi_config(
-        {
-            "TaskListParameter": {
-                "a": json.dumps(invalid_list_value),
-                "b": json.dumps(invalid_list_value),
-            }
-        }
-    ):
-        with pytest.raises(ValidationError, match="1 is less than the minimum of 10"):
-            luigi.build([TaskListParameter()], local_scheduler=True)
-
-
 def test_ratio_parameter(tmpdir):
     """Test the `luigi_tools.parameter.RatioParameter` class."""
 
@@ -264,6 +109,7 @@ class TestOptionalParameter:
 
     def test_optional_parameter(self, luigi_tools_working_directory):
         """Simple test for optional parameters."""
+
         # pylint: disable=too-many-statements
         class TaskFactory:
             """A class factory."""
@@ -914,7 +760,6 @@ def _check_parameter(*, obj, parameter, expected_dict, override_comparison_field
         # manually compare the attributes for expected differences with origin obj
         if override_comparison_fields:
             for attribute_name, attribute_value in override_comparison_fields.items():
-
                 actual_value = getattr(new_obj, attribute_name)
                 assert actual_value == attribute_value
         else:
